Crate supplement

Crate supplement 

Re-exports

pub use completion::Completion;
pub use completion::CompletionGroup;
pub use seen::Seen;

Modules

completion
The module for CLI completion output.
core
The module defining CLI objects, including Command, Flag and Arg.
error
Module defining the error types for this crate.
gen_prelude
helper
Helper functions/macros to make your life easier.
id
Module for IDs of CLI objects that can be used to lookup values in Seen.
seen
The module for values seen in the CLI.

Structs

Config
An object to configure how the code-gen should work e.g. to ignore some certain flags or subcommands.

Enums

Shell
Enum to represent different shell. Use str::parse to create it.

Functions

generate
Generate the scaffold for your completion based on clap::Command object. After importing the generated code, you can call core::Command::supplement to get the completion result.

Type Aliases

Result