Crate supplement

Crate supplement 

Re-exports

pub use completion::Completion;
pub use completion::CompletionGroup;
pub use completion::Shell;
pub use history::History;

Modules

completion
core
error
history
id

Structs

Config
An object to configure how the code-gen should work e.g. to ignore some certain flags or subcommands.

Functions

generate
Generate the scaffold for your completion based on clap object. After importing the generated code, you can call CMD.supplement(args) to get the completion result. The end product looks like this:

Type Aliases

Result